#!/usr/bin/python3

import xml.dom.minidom
import sqlite3 

conn = sqlite3.connect('rh.db')
conn.row_factory = sqlite3.Row

impl = xml.dom.minidom.DOMImplementation()
doctype = impl.createDocumentType(
    qualifiedName='rh',
    publicId='', 
    systemId='rh.dtd',
)    
doc = impl.createDocument('', 'rh', doctype)


def export_rh():

    root = doc.documentElement

    boss = conn.cursor()

    boss.execute('SELECT ID \
                  FROM EMPLOYE \
                  LEFT OUTER JOIN SUPERIEUR ON (EMPLOYE.ID = SUPERIEUR.ID_EMPLOYE) \
                  WHERE ID_SUPERIEUR IS NULL');

    for b in boss:
        root.appendChild(export_employe(b['id']))

    boss.close()


def export_employe(emp_id) :

    emp = conn.cursor()
    emp.execute('SELECT E.NOM      as e_nom, \
                        E.PRENOM   as e_prenom, \
                        E.EMBAUCHE as e_embauche, \
                        E.SALAIRE  as e_salaire, \
                        D.NOM      as d_nom, \
                        D.VILLE    as d_ville \
                 FROM EMPLOYE E, DEPARTEMENT D \
                 WHERE E.ID = ? AND E.ID_DEPT = D.ID', (emp_id,))
    e = emp.fetchone()

    employe = doc.createElement('employe')
    employe.setAttribute('id', str(emp_id))

    nom = doc.createElement('nom')
    nom.appendChild(doc.createTextNode(str(e['e_nom'])))
    employe.appendChild(nom)

    prenom  = doc.createElement('prenom')
    prenom.appendChild(doc.createTextNode(str(e['e_prenom'])))
    employe.appendChild(prenom)

    embauche = doc.createElement('embauche')
    embauche.appendChild(doc.createTextNode(str(e['e_embauche'])))
    employe.appendChild(embauche)

    salaire = doc.createElement('salaire')
    salaire.appendChild(doc.createTextNode(str(e['e_salaire'])))
    employe.appendChild(salaire)

    departement = doc.createElement('departement')
    departement.setAttribute('nom', e['d_nom'])
    departement.setAttribute('ville', e['d_ville'])
    employe.appendChild(departement)

    emp.close()


    sub = conn.cursor()
    sub.execute('SELECT ID_EMPLOYE FROM SUPERIEUR WHERE ID_SUPERIEUR = ?', (emp_id,));

    for s in sub :
        employe.appendChild(export_employe(s['id_employe']))

    sub.close()

    return employe



if __name__ == '__main__':
    export_rh()
    doc.writexml(open('rh-dom.xml','w'))
